@@ -21,7 +21,7 @@ def run_in_background(f):
     router_path = f"/run_in_background/{f.__name__}"
     new_r = APIRouter()
 
-    @new_r.put(router_path, tags=["background_tasks"], include_in_schema=False)
+    @new_r.post(router_path, tags=["background_tasks"], include_in_schema=False)
     async def endpoint(
             request: Request,
             task_id: str = Body(...),
